# eric7.Preferences.ConfigurationPages.ProjectPage

Module implementing the Project configuration page.

### Global Attributes

None

### Classes

ProjectPage | Class implementing the Project configuration page.

### Functions

create | Module function to create the configuration page.

## ProjectPage

Class implementing the Project configuration page.

### Derived from

ConfigurationPageBase, Ui_ProjectPage

### Class Attributes

None

### Class Methods

None

### Methods

ProjectPage | Constructor
save | Public slot to save the Project configuration.

### Static Methods

None

#### ProjectPage (Constructor)

ProjectPage()

Constructor

#### ProjectPage.save

save()

Public slot to save the Project configuration.

Up

## create

create(_dlg)

Module function to create the configuration page.

_dlg (ConfigurationDialog)
  reference to the configuration dialog (unused)

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up